@@ -186,45 +186,60 @@ def addControllerListTo(apiInstance, controllerList) :
         log.debug(addControllerListTo, f'{controller.url} -> {StringHelper.prettyPython(infoList)}')
         apiInstance.add_resource(controller, *urlList)
 
+
 @Function
 def addServiceListTo(apiInstance,serviceList) :
     for service in serviceList :
         apiInstance.bindResource(apiInstance,service())
 
+
 @Function
 def addSchedulerListTo(apiInstance,schedulerList) :
     for scheduler in schedulerList :
         apiInstance.bindResource(apiInstance,scheduler())
 
+
 @Function
 def addClientListTo(apiInstance,clientList) :
     for client in clientList :
         apiInstance.bindResource(apiInstance,client())
 
+
+@Function
+def addListenerTo(apiInstance,listenerList) :
+    for listener in listenerList :
+        apiInstance.bindResource(apiInstance,listener())
+
+
 @Function
 def addRepositoryTo(apiInstance, repositoryList) :
     for repository in repositoryList :
         apiInstance.bindResource(apiInstance,repository())
 
+
 @Function
 def addValidatorListTo(apiInstance,validatorList) :
     for validator in validatorList :
         apiInstance.bindResource(apiInstance,validator())
 
+
 def addMapperListTo(apiInstance,mapperList) :
     for mapper in mapperList :
         apiInstance.bindResource(apiInstance,mapper())
 
+
 @Function
 def addHelperListTo(apiInstance,helperList) :
     for helper in helperList :
         apiInstance.bindResource(apiInstance,helper())
 
+
 @Function
 def addConverterListTo(apiInstance,converterList) :
     for converter in converterList :
         apiInstance.bindResource(apiInstance,converter())
 
+
 class FlaskResource:
     ...
 
@@ -242,16 +257,19 @@ def addFlaskApiResources(
         schedulerList,
         serviceList,
         clientList,
+        listenerList,
         repositoryList,
         validatorList,
         mapperList,
         helperList,
-        converterList
+        converterList,
+        *args
     ) :
     addResourceAttibutes(apiInstance)
     addRepositoryTo(apiInstance, repositoryList)
     addSchedulerListTo(apiInstance, schedulerList)
     addClientListTo(apiInstance, clientList)
+    addListenerTo(apiInstance, listenerList)
     addServiceListTo(apiInstance, serviceList)
     addControllerListTo(apiInstance, controllerList)
     addValidatorListTo(apiInstance, validatorList)
